summaryrefslogtreecommitdiff
path: root/ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c
diff options
context:
space:
mode:
Diffstat (limited to 'ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c')
-rw-r--r--ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c b/ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c
index 0cf0766b9c..e8ea1f159d 100644
--- a/ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c
+++ b/ArmPkg/Library/ArmExceptionLib/ArmExceptionLib.c
@@ -103,7 +103,7 @@ InitializeCpuExceptionHandlers(
// if we are requested to copy exceptin handlers to another location
if (gArmRelocateVectorTable) {
- VectorBase = PcdGet32(PcdCpuVectorBaseAddress);
+ VectorBase = PcdGet64(PcdCpuVectorBaseAddress);
Status = CopyExceptionHandlers(VectorBase);
}
@@ -118,7 +118,7 @@ InitializeCpuExceptionHandlers(
// for encapsulated FVs.
ASSERT(((UINTN)ExceptionHandlersStart & gExceptionVectorAlignmentMask) == 0);
// We do not copy the Exception Table at PcdGet32(PcdCpuVectorBaseAddress). We just set Vector
// Base Address to point into CpuDxe code.
VectorBase = (UINTN)ExceptionHandlersStart;
@@ -118,7 +118,7 @@ InitializeCpuExceptionHandlers(
// for encapsulated FVs.
ASSERT(((UINTN)ExceptionHandlersStart & gExceptionVectorAlignmentMask) == 0);
- // We do not copy the Exception Table at PcdGet32(PcdCpuVectorBaseAddress). We just set Vector
+ // We do not copy the Exception Table at PcdGet64(PcdCpuVectorBaseAddress). We just set Vector
// Base Address to point into CpuDxe code.
VectorBase = (UINTN)ExceptionHandlersStart;